@@ -2,6 +2,11 @@
 '''
 User interface utilities
 '''
+
+from __future__ import print_function
+
+from bwikibot.utils import skip_boring_lines
+
 #from mako.template import Template
 
 colors = {
@@ -27,7 +32,7 @@ def print_diff(text_a, text_b):
     b_lines = text_b.splitlines(1)
     diff = ndiff(a_lines, b_lines)
 
-    for line in diff:
+    for line in skip_boring_lines(diff, lambda x: x[0] == ' '):
         cprint(line[:-1], color=line[0])
 
 def ask_y_n(question):
